#!/usr/bin/env python3
# coding: utf-8
# Copyright 2024 Huawei Technologies Co., Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
# ===========================================================================
from itertools import chain

EOL_CARD = ["A300-3000", "A300-3010"]
EOL_MODEL = ["Atlas 200I Soc A1"]
CARD_DICT = {
    "A300i-pro": [
        "Ubuntu_20.04_aarch64",
        "Ubuntu_20.04_x86_64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64",
        "OpenEuler_20.03LTS_aarch64",
        "OpenEuler_20.03LTS_x86_64",
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Kylin_V10Tercel_aarch64",
        "Kylin_V10Tercel_x86_64",
        "Kylin_V10Sword_aarch64",
        "Kylin_V10Sword_x86_64",
        "Kylin_V10Lance_aarch64",
        "CentOS_7.6_aarch64",
        "CentOS_7.6_x86_64",
        "EulerOS_2.9_aarch64",
        "EulerOS_2.9_x86_64",
        "EulerOS_2.10_aarch64",
        "EulerOS_2.10_x86_64",
        "BCLinux_21.10_aarch64"
    ],
    "A300i-duo": [
        "Ubuntu_20.04_aarch64",
        "Ubuntu_20.04_x86_64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64",
        "BCLinux_21.10_aarch64"

    ],
    "A200i-a2": [
        "Kylin_V10_aarch64"
    ],
    "A300T-9000": [
        "Ubuntu_18.04_x86_64",
        "Ubuntu_18.04_aarch64",
        "Ubuntu_20.04_aarch64",
        "Ubuntu_20.04_x86_64",
        "OpenEuler_20.03LTS_aarch64",
        "OpenEuler_20.03LTS_x86_64",
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Kylin_V10Tercel_aarch64",
        "Kylin_V10Tercel_x86_64",
        "Kylin_V10Sword_aarch64",
        "CentOS_7.6_aarch64",
        "CentOS_7.6_x86_64",
        "UOS_20-1020e_aarch64",
        "EulerOS_2.8_aarch64",
        "EulerOS_2.9_aarch64",
        "EulerOS_2.9_x86_64",
        "EulerOS_2.10_aarch64",
        "EulerOS_2.10_x86_64"
    ],
    "A900T": [
        "BCLinux_21.10_aarch64",
        "CTyunOS_22.06_aarch64",
        "EulerOS_2.10_aarch64",
        "EulerOS_2.10_x86_64",
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "CentOS_7.6_aarch64",
        "CentOS_7.6_x86_64",
        "Kylin_V10_aarch64",
        "Kylin_V10Sword_aarch64",
        "Kylin_V10Lance_aarch64",
        "UOS_20-1050e_aarch64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64",
        "CULinux_3.0_aarch64"
    ],
    "A300t-a2": [
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64"
    ],
    "Atlas 800I A2": [
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64",
        "Kylin_V10Lance_aarch64",
        "BCLinux_21.10_aarch64"
    ],
    "Atlas 900 A3 SuperPod": [
        "Debian_10_aarch64",
        "OpenEuler_22.03LTS_aarch64"
    ]
}
MODEL_TAGS_NOT_SUPPORT = {
    "Atlas 500 Pro (Model 3000)": [
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "clusterd",
        "ascend-operator"
    ],
    "Atlas 500 Pro(Model 3000)": [
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "clusterd",
        "ascend-operator"
    ]
}
OS_ARCH_TAGS_SUPPORT = {
    "CentOS_7.6_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "CentOS_7.6_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "BCLinux_21.10_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "mindio",
        "clusterd"
    ],
    "CULinux_3.0_aarch64": [
        "driver",
        "firmware",
        "kernels",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "sys_pkg",
        "tfplugin",
        "toolbox",
        "toolkit",
        "fault-diag"
    ],
    "CTyunOS_22.06_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "mindio",
        "fault-diag"
    ],
    "CTyunOS_22.06_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "mindio",
        "fault-diag"
    ],
    "EulerOS_2.8_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ha",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "EulerOS_2.9_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "EulerOS_2.9_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "EulerOS_2.10_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "EulerOS_2.10_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ha",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Kylin_V10_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "mindio",
        "fault-diag"
    ],
    "Kylin_V10Tercel_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "mindio",
        "fault-diag"
    ],
    "Kylin_V10Tercel_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "mindio",
        "fault-diag"
    ],
    "Kylin_V10Sword_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "mindio",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "mindio",
        "fault-diag"
    ],
    "Kylin_V10Lance_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "fault-diag"
    ],
    "OpenEuler_20.03LTS_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "OpenEuler_20.03LTS_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "OpenEuler_22.03LTS_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "OpenEuler_22.03LTS_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Ubuntu_18.04_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Ubuntu_18.04_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Ubuntu_20.04_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Ubuntu_20.04_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Ubuntu_22.04_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "Ubuntu_22.04_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ],
    "UOS_20-1020e_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "mindio",
        "dl",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator",
        "clusterd",
        "hccl-controller",
        "resilience-controller",
        "fault-diag"
    ],
    "Debian_10_aarch64": [
        "driver",
        "firmware",
        "kernels",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "sys_pkg",
        "toolbox",
        "toolkit",
        "tfplugin",
        "fault-diag"
    ],
    "UOS_20-1050e_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "mindio",
        "clusterd",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "fault-diag"
    ]
}


def show_os_card_table():
    try:
        from prettytable import PrettyTable
        all_os = list(set(chain(*CARD_DICT.values())))
        table = PrettyTable()
        table.field_names = ["OS"] + list(CARD_DICT.keys())
        for os_ in all_os:
            table.add_row([os_] + [("Y" if os_ in os_list else "N") for card, os_list in CARD_DICT.items()])
        print("OS and card table:")
        print(table)
    except Exception as e:
        print(e)


def show_os_tag_table():
    try:
        from prettytable import PrettyTable
        all_tags = list(set(chain(*OS_ARCH_TAGS_SUPPORT.values())))
        table = PrettyTable()
        table.field_names = ["OS"] + list(all_tags)
        for os_, tags in OS_ARCH_TAGS_SUPPORT.items():
            table.add_row([os_] + [("Y" if tag in tags else "N") for tag in all_tags])
        print("OS and tag table:")
        print(table)
    except Exception as e:
        print(e)


if __name__ == '__main__':
    show_os_card_table()
    show_os_tag_table()
